@@ -3,9 +3,9 @@ context("Testing the quantile functions.")
 
 test_that("qHoeffInd function returns correct values", {
   set.seed(9234)
-  xVals = rHoeffInd(5)
+  xVals <- rHoeffInd(5)
   for (i in 1:length(xVals)) {
-    p = pHoeffInd(xVals[i])
+    p <- pHoeffInd(xVals[i])
     expect_equal(qHoeffInd(p, 10^-3), xVals[i], tolerance = 10^-3)
   }
 
@@ -15,15 +15,17 @@ test_that("qHoeffInd function returns correct values", {
 
 test_that("qDisHoeffInd function returns correct values", {
   set.seed(9234)
-  sims = 10
+  sims <- 10
   for (i in 1:sims) {
-    p = runif(sample(1:5, 1))
-    p = p / sum(p)
-    q = runif(sample(1:5, 1))
-    q = q / sum(q)
-    x = rDisHoeffInd(1, p, q)
+    p <- runif(sample(1:5, 1))
+    p <- p / sum(p)
+    q <- runif(sample(1:5, 1))
+    q <- q / sum(q)
+    x <- rDisHoeffInd(1, p, q)
     expect_equal(qDisHoeffInd(pDisHoeffInd(x, p, q), p, q, 10^-4),
-                 x, tolerance = 10^-3)
+      x,
+      tolerance = 10^-3
+    )
   }
 
   expect_error(qDisHoeffInd(-.01, 1, 1))
@@ -32,13 +34,15 @@ test_that("qDisHoeffInd function returns correct values", {
 
 test_that("qMixHoeffInd function returns correct values", {
   set.seed(9234)
-  sims = 10
+  sims <- 10
   for (i in 1:sims) {
-    p = runif(sample(1:5, 1))
-    p = p / sum(p)
-    x = rMixHoeffInd(1, p)
+    p <- runif(sample(1:5, 1))
+    p <- p / sum(p)
+    x <- rMixHoeffInd(1, p)
     expect_equal(qMixHoeffInd(pMixHoeffInd(x, p), p, 10^-4),
-                 x, tolerance = 10^-3)
+      x,
+      tolerance = 10^-3
+    )
   }
 
   expect_error(qDisHoeffInd(-.01, 1, 1))
